package net.lensfrex.rd.controller.activity;

import cn.dev33.satoken.annotation.SaCheckRole;
import net.lensfrex.rd.data.entity.table.Activity;
import net.lensfrex.rd.data.model.request.admin.ActivityInfoDto;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.data.model.response.ResponseCode;
import net.lensfrex.rd.exception.data.DataConflictException;
import net.lensfrex.rd.service.activity.ActivityService;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/admin/activity")
public class AdminActivityController {

    private final ActivityService activityService;

    public AdminActivityController(ActivityService activityService) {
        this.activityService = activityService;
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/add")
    public Response<Activity> add(@RequestBody ActivityInfoDto request) {
        try {
            activityService.addActivity(request);
        } catch (DataConflictException e) {
            return Response.error(ResponseCode.PARAM_WRONG, "同一个学期内一个时间段内只能有一个选课活动");
        }

        return Response.success();
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/update")
    public Response<Activity> update(@RequestParam("id") String id, @RequestBody ActivityInfoDto request) {
        try {
            var activity = activityService.update(id, request);
            return Response.success(activity);
        } catch (DataConflictException e) {
            return Response.error(ResponseCode.PARAM_WRONG, "同一个学期内一个时间段内只能有一个选课活动");
        }
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/delete")
    public Response<Activity> delete(@RequestParam("id") String id) {
        activityService.delete(id);
        return Response.success();
    }
}
