package net.lensfrex.rd.controller.schedule;

import cn.dev33.satoken.annotation.SaCheckRole;
import net.lensfrex.rd.data.dto.schedule.CourseScheduleDTO;
import net.lensfrex.rd.data.entity.table.CourseSchedule;
import net.lensfrex.rd.data.model.request.schedule.ClassScheduleRequest;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.service.schedule.CourseScheduleService;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;

@RestController
@RequestMapping("/admin/course-schedule")
public class AdminScheduleController {

    private final CourseScheduleService courseScheduleService;

    public AdminScheduleController(CourseScheduleService courseScheduleService) {
        this.courseScheduleService = courseScheduleService;
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/add")
    public Response<CourseSchedule> add(@RequestBody ClassScheduleRequest request) {
        var dto = convert(request);

        var newCourse = courseScheduleService.add(dto);

        return Response.success(newCourse);
    }

    @SaCheckRole("ADMIN")
    @RequestMapping("/duplicate")
    public Response<Object> info(@RequestParam("course") String course,
                                 @RequestParam("from") String sourceTerm,
                                 @RequestParam("to") String targetTerm) {
        courseScheduleService.duplicate(course, sourceTerm, targetTerm);
        return Response.success();
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/update")
    public Response<CourseSchedule> update(@RequestParam("id") String id, @RequestBody ClassScheduleRequest request) {
        var dto = convert(request);

        var newCourse = courseScheduleService.update(id, dto);

        return Response.success(newCourse);
    }

    private CourseScheduleDTO convert(ClassScheduleRequest request) {
        CourseScheduleDTO dto = new CourseScheduleDTO();
        dto.setName(request.getName());
        dto.setCourse(request.getCourse());
        dto.setStartWeek(request.getStartWeek());
        dto.setEndWeek(request.getEndWeek());
        dto.setTime(request.getEndWeek());
        dto.setWeekDay(request.getWeekDay());
        dto.setAcademicTerm(request.getTerm());
        dto.setPlace(request.getPlace());
        dto.setRatio(request.getRatio());
        dto.setDistribution(new HashMap<>());
        dto.setTime(request.getSection());
        dto.setTeacherIds(request.getTeachers());

        return dto;

    }

    @SaCheckRole("ADMIN")
    @PostMapping("/delete")
    public Response<Object> delete(@RequestParam("id") String id) {
        courseScheduleService.delete(id);
        return Response.success();
    }
}
