package net.lensfrex.rd.controller.schedule;

import cn.dev33.satoken.annotation.SaCheckRole;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.servlet.http.HttpServletResponse;
import net.lensfrex.rd.data.dto.schedule.CourseScheduleDTO;
import net.lensfrex.rd.data.entity.table.TeacherInfo;
import net.lensfrex.rd.data.model.response.PaginationWrapper;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.data.model.response.ResponseCode;
import net.lensfrex.rd.service.schedule.CourseScheduleService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;
import java.util.List;

@RestController
@RequestMapping("/course-schedule")
public class ScheduleController {

    private final CourseScheduleService courseScheduleService;
    private final ObjectMapper objectMapper;

    public ScheduleController(CourseScheduleService courseScheduleService, ObjectMapper objectMapper) {
        this.courseScheduleService = courseScheduleService;
        this.objectMapper = objectMapper;
    }

    @RequestMapping("/list")
    public Response<PaginationWrapper<List<CourseScheduleDTO>>> list(
            @RequestParam(value = "course") String course,
            @RequestParam(value = "page", required = false, defaultValue = "1") int page,
            @RequestParam(value = "pageSize", required = false, defaultValue = "10") int pageSize) {

        var result = courseScheduleService.getScheduleOfCourse(course, page, pageSize);
        return Response.success(result);
    }

    @RequestMapping("/list-term")
    public Response<List<CourseScheduleDTO>> getAllForCourse(
            @RequestParam(value = "course") String course,
            @RequestParam(value = "term") String term
    ) {

        var result = courseScheduleService.getTermCourseSchedule(course, term);
        return Response.success(result);
    }

    @RequestMapping("/list-teachers")
    public Response<List<TeacherInfo>> listTeachers(@RequestParam("id") String scheduleId) {
        var result = courseScheduleService.getScheduleTeacherInfo(scheduleId);
        return Response.success(result);
    }

    @RequestMapping("/info")
    public Response<CourseScheduleDTO> info(@RequestParam("id") String id) {
        var result = courseScheduleService.getScheduleDTO(id);
        return Response.success(result);
    }

    @RequestMapping("/selected-count")
    public Response<Integer> selectCount(@RequestParam("id") String id) {
        var result = courseScheduleService.getSelectedCount(id);
        return Response.success(result);
    }

    private class ASD {

    }

    protected class  asdd {

    }
    @SaCheckRole({"TEACHER", "ADMIN"})
    @RequestMapping("/list-student")
    public void exportStudents(@RequestParam("id") String scheduleId, HttpServletResponse response) throws IOException {
        if (scheduleId == null) {
            Response<String> responseData = Response.error(ResponseCode.PARAM_WRONG);
            response.setContentType("application/json");
            response.getWriter().write(objectMapper.writeValueAsString(responseData));
            return;
        }

        var data = courseScheduleService.exportStudentExcel(scheduleId);

        if (data == null) {
            Response<String> responseData = Response.success("数据是空的");
            response.setContentType("application/json");
            response.getWriter().write(objectMapper.writeValueAsString(responseData));
            return;
        }

        response.setContentLength(data.length);
        response.setContentType("application/octet-stream");
        response.setHeader("Content-Disposition", String.format("attachment; filename=\"%s\"", "export_students_" + scheduleId + ".xlsx"));

        response.setHeader("Cache-Control", "no-cache, no-store, must-revalidate");
        response.setHeader("Pragma", "no-cache");
        response.setHeader("Cache-Control", "no-cache, no-store, must-revalidate");

        response.getOutputStream().write(data);
    }
}
