package net.lensfrex.rd.controller.schedule;

import cn.dev33.satoken.annotation.SaCheckRole;
import cn.dev33.satoken.stp.StpUtil;
import cn.wustlinghang.mywust.data.common.Course;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import cn.wustlinghang.mywust.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.data.dto.schedule.CourseScheduleDTO;
import net.lensfrex.rd.data.entity.table.TeacherInfo;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.service.official.OfficialUndergradScheduleService;
import net.lensfrex.rd.service.schedule.CourseScheduleService;
import net.lensfrex.rd.service.schedule.StudentCourseScheduleService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@RestController
@RequestMapping("/student/course-schedule")
public class StudentScheduleController {

    private final CourseScheduleService courseScheduleService;
    private final OfficialUndergradScheduleService officialUndergradScheduleService;
    private final StudentCourseScheduleService studentCourseScheduleService;

    public StudentScheduleController(CourseScheduleService courseScheduleService,
                                     OfficialUndergradScheduleService officialUndergradScheduleService,
                                     StudentCourseScheduleService studentCourseScheduleService) {

        this.courseScheduleService = courseScheduleService;
        this.officialUndergradScheduleService = officialUndergradScheduleService;
        this.studentCourseScheduleService = studentCourseScheduleService;
    }

    @SaCheckRole("STUDENT")
    @RequestMapping("/current")
    public Response<List<CourseScheduleDTO>> list(@RequestParam(value = "term", required = false, defaultValue = "") String term) {
        if (term == null || term.isEmpty()) {
            term = StringUtil.getCurrentTermString();
        }

        String uid = StpUtil.getLoginId().toString();
        var result = courseScheduleService.getStudentTermSchedule(uid, term);

        return Response.success(result);
    }

    @SaCheckRole("STUDENT")
    @RequestMapping("/official")
    public Response<List<CourseScheduleDTO>> getOfficialCourse(
            @RequestParam(value = "term", required = false, defaultValue = "") String term)
            throws IOException, ParseException, ApiException {

        if (term == null || term.equals("")) {
            term = StringUtil.getCurrentTermString();
            log.debug("默认的学期：" + term);
        }

        String uid = StpUtil.getLoginId().toString();
        var schedules = officialUndergradScheduleService.getOfficialCourseSchedule(uid, term);

        var result = new ArrayList<CourseScheduleDTO>(schedules.size());
        for (var schedule : schedules) {
            result.add(convert(schedule));
        }

        return Response.success(result);
    }

    private CourseScheduleDTO convert(Course course) {
        CourseScheduleDTO courseScheduleDTO = new CourseScheduleDTO();
        courseScheduleDTO.setName(course.getName());
        courseScheduleDTO.setCourse(course.getName());
        courseScheduleDTO.setStartWeek(course.getStartWeek());
        courseScheduleDTO.setEndWeek(course.getEndWeek());
        courseScheduleDTO.setTime(course.getStartSection() / 2);
        courseScheduleDTO.setWeekDay(course.getWeekDay());
        courseScheduleDTO.setPlace(course.getClassroom());
        courseScheduleDTO.setDistribution(null);

        List<TeacherInfo> teachers = new ArrayList<>();
        teachers.add(TeacherInfo.builder().name(course.getTeacher()).build());
        courseScheduleDTO.setTeachers(teachers);

        return courseScheduleDTO;
    }

    @SaCheckRole("STUDENT")
    @RequestMapping("/select")
    public Response<Object> select(@RequestParam("schedule") String schedule, @RequestParam("activity") String activity) {
        String uid = StpUtil.getLoginId().toString();

        studentCourseScheduleService.selectSchedule(uid, schedule, activity);

        return Response.success();
    }
}
