package net.lensfrex.rd.controller.score;

import cn.dev33.satoken.annotation.SaCheckRole;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.servlet.http.HttpServletResponse;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.data.model.response.ResponseCode;
import net.lensfrex.rd.service.score.ScoreService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;

@RestController
@RequestMapping("/score")
public class ScoreController {
    private final ScoreService scoreService;

    private final ObjectMapper objectMapper;

    public ScoreController(ScoreService scoreService, ObjectMapper objectMapper) {
        this.scoreService = scoreService;
        this.objectMapper = objectMapper;
    }

    @SaCheckRole({"TEACHER", "ADMIN"})
    @RequestMapping("/export")
    public void exportStudents(@RequestParam("id") String scheduleId, HttpServletResponse response) throws IOException {
        if (scheduleId == null) {
            Response<String> responseData = Response.error(ResponseCode.PARAM_WRONG);
            response.setContentType("application/json");
            response.getWriter().write(objectMapper.writeValueAsString(responseData));
            return;
        }

        var data = scoreService.exportScoreExcel(scheduleId);

        if (data == null) {
            Response<String> responseData = Response.success("数据是空的");
            response.setContentType("application/json");
            response.getWriter().write(objectMapper.writeValueAsString(responseData));
            return;
        }

        response.setContentLength(data.length);
        response.setContentType("application/octet-stream");
        response.setHeader("Content-Disposition", String.format("attachment; filename=\"%s\"", "export_score_" + scheduleId + ".xlsx"));

        response.setHeader("Cache-Control", "no-cache, no-store, must-revalidate");
        response.setHeader("Pragma", "no-cache");
        response.setHeader("Cache-Control", "no-cache, no-store, must-revalidate");

        response.getOutputStream().write(data);
    }
}
