package net.lensfrex.rd.controller.student;

import cn.dev33.satoken.annotation.SaCheckRole;
import net.lensfrex.rd.data.dto.user.student.BasicStudentInfoDto;
import net.lensfrex.rd.data.dto.user.student.NewStudentDTO;
import net.lensfrex.rd.data.dto.user.student.StudentUserBasicDTO;
import net.lensfrex.rd.data.dto.user.student.StudentUserInfoDTO;
import net.lensfrex.rd.data.dto.user.teacher.TeacherUserDTO;
import net.lensfrex.rd.data.entity.table.StudentInfo;
import net.lensfrex.rd.data.entity.table.TeacherInfo;
import net.lensfrex.rd.data.model.request.admin.StudentAddRequest;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.data.model.response.ResponseCode;
import net.lensfrex.rd.service.user.StudentUserService;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/admin/user/student")
public class AdminStudentController {
    private final StudentUserService studentUserService;

    public AdminStudentController(StudentUserService studentUserService) {
        this.studentUserService = studentUserService;
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/add")
    public Response<StudentInfo> add(@RequestBody StudentAddRequest request) {
        var dto = new BasicStudentInfoDto(request.studentNumber(), request.studentName(), request.major());

        var teacherInfo = studentUserService.add(dto);
        return Response.success(teacherInfo);
    }

    @SaCheckRole("ADMIN")
    @PostMapping("/add-with-auto-major")
    public Response<StudentInfo> addWithAutoMajor(@RequestBody StudentAddRequest request) {
        if (request.studentNumber() == null || request.studentName() == null || request.major() == null) {
            return Response.error(ResponseCode.PARAM_WRONG);
        }
        var dto = new BasicStudentInfoDto(request.studentNumber(), request.studentName(), request.major());

        var teacherInfo = studentUserService.addWithAutoMajor(dto);
        return Response.success(teacherInfo);
    }
//
//    @SaCheckRole("ADMIN")
//    @PostMapping("/update")
//    public Response<StudentInfo> update(@RequestParam("id") String id, @RequestBody StudentAddRequest request) {
//        String username = request.studentNumber();
//        String teacherName = request.studentName();
//        String initialPassword = request.initialPassword();
//
//        var dto = new BasicStudentInfoDto(request.studentNumber(), request.studentName());
//
//        var teacherInfo = studentUserService.update(id, dto);
//
//        return Response.success(teacherInfo);
//    }

    @SaCheckRole("ADMIN")
    @PostMapping("/delete")
    public Response<TeacherInfo> delete(@RequestParam("id") String id) {
        studentUserService.delete(id);
        return Response.success();
    }
}
