package net.lensfrex.rd.data.model.response;


import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * 通用的响应
 *
 * @param code 响应码
 * @param msg  响应信息
 * @param data 响应数据
 * @param <T>  data的类型
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
public record Response<T>(int code, String msg, T data) {
    public static <T> Response<T> success(T data) {
        return new Response<>(ResponseCode.SUCCESS.getCode(), "ok", data);
    }

    public static <T> Response<T> success() {
        return success(null);
    }

    public static <T> Response<T> error(int code, String message) {
        return new Response<>(code, message, null);
    }

    public static <T> Response<T> error(ResponseCode code) {
        return error(code.getCode(), code.getMessage());
    }

    public static <T> Response<T> error(ResponseCode code, String message) {
        return error(code.getCode(), message);
    }
}