package net.lensfrex.rd.exception;

import cn.dev33.satoken.exception.SaTokenException;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.data.model.response.Response;
import net.lensfrex.rd.data.model.response.ResponseCode;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.web.HttpMediaTypeNotSupportedException;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.method.annotation.MethodArgumentTypeMismatchException;

@Slf4j
@ControllerAdvice
public class GlobalExceptionHandler {
    @ResponseBody
    @ExceptionHandler(BaseException.class)
    public Response<Object> baseException(BaseException e) {
        return Response.error(ResponseCode.INVALID_REQUEST, e.getMessage());
    }

    @ResponseBody
    @ExceptionHandler(ApiException.class)
    public Response<Object> baseException(ApiException e) {
        return Response.error(ResponseCode.SERVER_INTERNAL_ERROR, e.getMessage());
    }

    @ResponseBody
    @ExceptionHandler(ParseException.class)
    public Response<Object> baseException(ParseException e) {
        return Response.error(ResponseCode.SERVER_INTERNAL_ERROR,
                "mywust解析数据错误，请联系开发者，或者到https://github.com/LingHangStudio/mywust/issues提交问题，多谢啦"
        );
    }

    @ResponseBody
    @ExceptionHandler(SaTokenException.class)
    public Response<Object> baseException(SaTokenException e) {
        return Response.error(ResponseCode.PERMISSION_DENIED, e.getMessage());
    }

    @ResponseBody
    @ExceptionHandler(Exception.class)
    public Response<Object> baseException(Exception e) {
        log.error("未处理的异常：", e);
        return Response.error(ResponseCode.SERVER_INTERNAL_ERROR);
    }


    /**
     * 处理参数不完整的请求异常
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(MissingServletRequestParameterException.class)
    public Response<Object> handler(MissingServletRequestParameterException e) {
        log.debug("请求的参数不完整: " + e.getMessage());
        return Response.error(ResponseCode.PARAM_WRONG);
    }

    /**
     * 处理参数类型错误的请求异常（请求参数类型错误）
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(MethodArgumentTypeMismatchException.class)
    public Response<Object> handler(MethodArgumentTypeMismatchException e) {
        log.debug(String.format("请求错误（%s）: %s", e.getClass().getName(), e.getMessage()));
        return Response.error(ResponseCode.PARAM_WRONG);
    }

    /**
     * 处理参数类型错误的请求异常2（Json解析错误）
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(JsonMappingException.class)
    public Response<Object> handler(JsonMappingException e) {
        log.debug(String.format("请求错误（%s）: %s", e.getClass().getName(), e.getMessage()));
        return Response.error(ResponseCode.PARAM_WRONG);
    }

    /**
     * 处理参数类型错误的请求异常3（字段映射错误）
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(HttpMessageNotReadableException.class)
    public Response<Object> handler(HttpMessageNotReadableException e) {
        log.debug(String.format("请求错误（%s）: %s", e.getClass().getName(), e.getMessage()));
        return Response.error(ResponseCode.PARAM_WRONG);
    }

    /**
     * 处理请求头中“Content-Type”字段不正确的异常
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(HttpMediaTypeNotSupportedException.class)
    public Response<Object> handler(HttpMediaTypeNotSupportedException e) {
        log.debug(String.format("请求错误（%s）: %s", e.getClass().getName(), e.getMessage()));
        return Response.error(ResponseCode.PARAM_WRONG, "请求头\"Contene-Type\"字段有误");
    }

    /**
     * 处理请求方法错误的情况
     *
     * @param e 异常
     * @return 统一响应
     */
    @ResponseBody
    @ExceptionHandler(HttpRequestMethodNotSupportedException.class)
    public Response<Object> handler(HttpRequestMethodNotSupportedException e) {
        log.debug(String.format("请求错误（%s）: %s", e.getClass().getName(), e.getMessage()));
        return Response.error(ResponseCode.INVALID_REQUEST);
    }
}