package net.lensfrex.rd.service.auth;

import cn.dev33.satoken.stp.StpInterface;
import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.data.enums.UserType;
import net.lensfrex.rd.data.entity.table.UserBasic;
import net.lensfrex.rd.service.user.UserBasicService;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;

@Slf4j
@Service
public class UserTypeStpInterfaceImpl implements StpInterface {
    private static final Cache<String, List<String>> userRoleCache = Caffeine.newBuilder()
            .expireAfterAccess(15, TimeUnit.DAYS)
            .initialCapacity(256)
            .maximumSize(2048)
            .build();

    private static final List<String> EMPTY_ARRAY = List.of();

    private final UserBasicService userBasicService;

    public UserTypeStpInterfaceImpl(UserBasicService userBasicService) {
        this.userBasicService = userBasicService;
    }

    @Override
    public List<String> getPermissionList(Object uid, String loginType) {
        List<String> permissions = new ArrayList<>();
        permissions.add("all");

        return permissions;
    }

    @Override
    public List<String> getRoleList(Object uid, String loginType) {
        List<String> roles = userRoleCache.getIfPresent(uid.toString());
        if (roles != null) {
            log.info("使用缓存的用户角色，用户：{}", uid);
            return roles;
        } else {
            roles = new ArrayList<>(1);
        }

        UserBasic userBasic = userBasicService.getUserBasicById(uid.toString());
        if (userBasic == null) {
            return EMPTY_ARRAY;
        }

        roles.add(switch (userBasic.getType()) {
            case 0 -> UserType.STUDENT.name();
            case 1 -> UserType.TEACHER.name();
            case 2 -> UserType.ADMIN.name();
            default -> {
                log.warn("未知的用户类型：{}", userBasic.getType());
                yield UserType.STUDENT.name();
            }
        });

        userRoleCache.put(uid.toString(), roles);
        return roles;
    }
}
