package net.lensfrex.rd.service.official;

import cn.wustlinghang.mywust.core.request.service.auth.UndergraduateLogin;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.network.RequestClientOption;
import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.exception.internal.JwcAuthException;
import net.lensfrex.rd.exception.internal.JwcNetworkException;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.concurrent.TimeUnit;

@Slf4j
@Service
public class OfficialUndergradAuthService {
    private static final Cache<String, String> cookieCache = Caffeine.newBuilder()
            .expireAfterWrite(2, TimeUnit.HOURS)
            .initialCapacity(256)
            .maximumSize(2048)
            .build();

    private final UndergraduateLogin undergraduateLogin;

    private final RequestClientOption requestClientOption;

    public OfficialUndergradAuthService(UndergraduateLogin undergraduateLogin,
                                        RequestClientOption requestClientOption) {
        this.undergraduateLogin = undergraduateLogin;
        this.requestClientOption = requestClientOption;
    }

    public String getCookie(String username, String password) {
        String cookie = cookieCache.getIfPresent(username);
        if (cookie != null) {
            try {
                boolean cookieValid = undergraduateLogin.testCookie(cookie);
                if (cookieValid) {
                    return cookie;
                }
            } catch (ApiException e) {
                throw new JwcAuthException(e.getCodeDescribe());
            } catch (Exception e) {
                log.warn("测试cookie出现异常, {}", e.toString());
                log.debug("", e);
            }
        }

        return renewCookie(username, password);
    }

    private String renewCookie(String username, String password) {
        try {
            return undergraduateLogin.getLoginCookie(username, password, requestClientOption);
        } catch (IOException e) {
            throw new JwcNetworkException();
        } catch (ApiException e) {
           throw new JwcAuthException(e.getCodeDescribe());
        }
    }
}
