package net.lensfrex.rd.service.official;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradCourseTableParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradCourseTableApiService;
import cn.wustlinghang.mywust.data.common.Course;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import cn.wustlinghang.mywust.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.configure.PasswordConfigure;
import net.lensfrex.rd.service.user.StudentUserService;
import net.lensfrex.rd.service.user.UserBasicService;
import net.lensfrex.rd.util.PasswordUtil;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.List;

@Slf4j
@Service
public class OfficialUndergradScheduleService {
    private final OfficialUndergradAuthService authService;
    private final UndergradCourseTableApiService apiService;
    private final UndergradCourseTableParser parser;

    private final UserBasicService userBasicService;
    private final StudentUserService studentUserService;

    private final PasswordUtil passwordUtil;

    public OfficialUndergradScheduleService(OfficialUndergradAuthService authService,
                                            UndergradCourseTableApiService apiService,
                                            UndergradCourseTableParser parser,
                                            UserBasicService userBasicService,
                                            PasswordConfigure passwordConfigure,
                                            StudentUserService studentUserService) {

        this.authService = authService;
        this.apiService = apiService;
        this.parser = parser;

        this.userBasicService = userBasicService;
        this.studentUserService = studentUserService;

        this.passwordUtil = new PasswordUtil(passwordConfigure.getKey(), passwordConfigure.getIv());
    }

    public List<Course> getOfficialCourseSchedule(String username, String password, String term) throws IOException, ApiException, ParseException {
        if (term == null) {
            term = StringUtil.getCurrentTermString();
        }

        String cookie = authService.getCookie(username, password);
        String page = apiService.getPage(term, cookie);

        return parser.parse(page);
    }

    public List<Course> getOfficialCourseSchedule(String uid, String term) throws IOException, ParseException, ApiException {
        var user = userBasicService.getUserBasicById(uid);
        var username = user.getUsername();
        var password = passwordUtil.decode(user.getPassword());

        return getOfficialCourseSchedule(username, password, term);
    }

    public List<Course> getOfficialCourseScheduleByStudentNumber(String studentNumber, String term) throws IOException, ParseException, ApiException {
        var student = studentUserService.getByStudentNumber(studentNumber);
        var username = student.username();
        var password = passwordUtil.decode(student.password());

        return getOfficialCourseSchedule(username, password, term);
    }
}

