package net.lensfrex.rd.service.official;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradStudentInfoPageParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradStudentInfoApiService;
import cn.wustlinghang.mywust.data.common.StudentInfo;
import cn.wustlinghang.mywust.exception.ApiException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.IOException;

@Slf4j
@Service
public class OfficialUndergradStudentInfoService {
    private final OfficialUndergradAuthService authService;

    private final UndergradStudentInfoApiService apiService;

    private final UndergradStudentInfoPageParser parser;

    public OfficialUndergradStudentInfoService(OfficialUndergradAuthService authService,
                                               UndergradStudentInfoApiService apiService,
                                               UndergradStudentInfoPageParser parser) {
        this.authService = authService;
        this.apiService = apiService;
        this.parser = parser;
    }

    public StudentInfo getNewStudentInfo(String username, String password) {
        try {
            String cookie = authService.getCookie(username, password);
            String page = apiService.getPage(cookie);
            return parser.parse(page);
        } catch (ApiException e) {
            log.warn("请求教务处学生信息发生api异常：{}", e.toString());
        } catch (IOException e) {
            log.warn("请求教务处学生信息发生网络异常：{}", e.toString());
        } catch (Exception e) {
            log.warn("请求教务处学生信息发生异常：{}", e.toString());
            log.debug("", e);
        }

        return new StudentInfo();
    }
}
