package net.lensfrex.rd.service.schedule;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.yitter.idgen.YitIdHelper;
import net.lensfrex.rd.dao.mapper.schedule.CourseScheduleMapper;
import net.lensfrex.rd.dao.mapper.schedule.CourseScheduleSelectionMapper;
import net.lensfrex.rd.data.entity.table.CourseSchedule;
import net.lensfrex.rd.data.entity.table.CourseSelection;
import net.lensfrex.rd.exception.data.DataNotExistsException;
import net.lensfrex.rd.exception.data.DataNotMatchException;
import net.lensfrex.rd.service.activity.ActivityService;
import net.lensfrex.rd.service.course.CourseService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;

@Service
public class StudentCourseScheduleService {

    private final ActivityService activityService;
    private final CourseScheduleMapper courseScheduleMapper;
    private final CourseService courseService;
    private final CourseScheduleService courseScheduleService;
    private final CourseScheduleSelectionMapper courseScheduleSelectionMapper;

    public StudentCourseScheduleService(ActivityService activityService,
                                        CourseScheduleMapper courseScheduleMapper, CourseService courseService,
                                        CourseScheduleService courseScheduleService,
                                        CourseScheduleSelectionMapper courseScheduleSelectionMapper) {

        this.activityService = activityService;
        this.courseScheduleMapper = courseScheduleMapper;
        this.courseService = courseService;
        this.courseScheduleService = courseScheduleService;
        this.courseScheduleSelectionMapper = courseScheduleSelectionMapper;
    }

    @Transactional
    public void selectSchedule(String uid, String scheduleId, String activityId) {
        var schedule = courseScheduleService.getSchedule(scheduleId);
        if (schedule == null) {
            throw new DataNotExistsException();
        }

        var activity = activityService.getById(activityId);
        if (activity == null) {
            throw new DataNotExistsException();
        }

        if (!schedule.getAcademicTerm().equals(activity.getTerm())) {
            throw new DataNotMatchException();
        }

        var schedulesOfCourseList = courseScheduleService.getTermCourseSchedule(schedule.getCourse(), schedule.getAcademicTerm());
        var schedulesOfCourseIdList = new ArrayList<String>(schedulesOfCourseList.size());
        for (var scheduleOfCourse : schedulesOfCourseList) {
            schedulesOfCourseIdList.add(scheduleOfCourse.getId());
        }

        var selectedScheduleList = courseScheduleSelectionMapper.selectList(new QueryWrapper<CourseSelection>()
                .eq("student", uid)
                .eq("activity", activityId)
                .eq("deleted", false)
        );

        for (var selectedCourse : selectedScheduleList) {
            if (schedulesOfCourseIdList.contains(selectedCourse.getSchedule())) {
                this.update(uid, selectedCourse.getSchedule(), scheduleId, activityId);
                return;
            }
        }

        String id = Long.toString(YitIdHelper.nextId());
        CourseSelection courseSelection = new CourseSelection();
        courseSelection.setId(id);
        courseSelection.setStudent(uid);
        courseSelection.setSchedule(scheduleId);
        courseSelection.setActivity(activityId);
        courseSelection.setCreateTime(LocalDateTime.now());
        courseSelection.setEditTime(LocalDateTime.now());
        courseSelection.setDeleted(false);

        courseScheduleSelectionMapper.insert(courseSelection);
    }

    @Transactional
    public void update(String uid, String oldSchedule, String newSchedule, String activityId) {
        CourseSelection courseSelection = new CourseSelection();
        courseSelection.setSchedule(newSchedule);
        courseSelection.setEditTime(LocalDateTime.now());
        courseScheduleSelectionMapper.update(courseSelection, new QueryWrapper<CourseSelection>()
                .eq("schedule", oldSchedule)
                .eq("activity", activityId)
                .eq("student", uid)
                .eq("deleted", false)
        );
    }
}
