package net.lensfrex.rd.service.user;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import lombok.extern.slf4j.Slf4j;
import net.lensfrex.rd.dao.mapper.user.StudentInfoMapper;
import net.lensfrex.rd.dao.mapper.user.TeacherInfoMapper;
import net.lensfrex.rd.data.entity.table.StudentInfo;
import net.lensfrex.rd.data.entity.table.TeacherInfo;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

@Slf4j
@Service
public class UserInfoService {

    private static final Cache<String, Object> cache = Caffeine.newBuilder()
            .expireAfterWrite(2, TimeUnit.DAYS)
            .initialCapacity(256)
            .maximumSize(2048)
            .build();

    private final StudentInfoMapper studentInfoMapper;

    private final TeacherInfoMapper teacherInfoMapper;

    public UserInfoService(StudentInfoMapper studentInfoMapper, TeacherInfoMapper teacherInfoMapper) {
        this.studentInfoMapper = studentInfoMapper;
        this.teacherInfoMapper = teacherInfoMapper;
    }

    public void invalidateCache(String id) {
        cache.invalidate(id);
    }

    public StudentInfo getAsStudent(String id, boolean useCache) {
        Object info = cache.getIfPresent(id);
        if (useCache && info != null) {
            log.debug("使用缓存的用户信息，用户id：{}", id);
            return (StudentInfo) info;
        }

        info = studentInfoMapper.selectOne(new QueryWrapper<StudentInfo>()
                .select("id", "student_number", "name", "major", "grade", "class")
                .eq("id", id)
                .eq("deleted", false)
        );

        cache.put(id, info);
        return (StudentInfo) info;
    }

    public StudentInfo getAsStudent(String id) {
        return getAsStudent(id, true);
    }

    public TeacherInfo getAsTeacher(String id, boolean useCache) {
        Object info = cache.getIfPresent(id);
        if (useCache && info != null) {
            log.debug("使用缓存的用户信息，用户id：{}", id);
            return (TeacherInfo) info;
        }

        info = teacherInfoMapper.selectOne(new QueryWrapper<TeacherInfo>()
                .select("id", "name")
                .eq("id", id)
                .eq("deleted", false)
        );

        cache.put(id, info);
        return (TeacherInfo) info;
    }

    public TeacherInfo getAsTeacher(String id) {
        return getAsTeacher(id, true);
    }
}
