package net.lensfrex.rd.util;

import cn.hutool.core.util.HexUtil;
import cn.hutool.crypto.Mode;
import cn.hutool.crypto.Padding;
import cn.hutool.crypto.symmetric.AES;
import cn.hutool.crypto.symmetric.SymmetricCrypto;

import java.nio.charset.StandardCharsets;
import java.util.StringJoiner;

public class PasswordUtil {
    private final SymmetricCrypto aes;

    public PasswordUtil(String key, String iv) {
        byte[] keyBytes = normalization(key);
        byte[] ivBytes = normalization(iv);

        this.aes = new AES(Mode.CBC, Padding.PKCS5Padding, keyBytes, ivBytes);
    }

    private static byte[] normalization(String key) {
        if (key.length() < 16) {
            StringJoiner sj = new StringJoiner(key);
            for (int i = 0; i < 16 - key.length(); i++) {
                sj.add("a");
            }
            key = sj.toString();
        } else if(key.length() > 16) {
            key = key.substring(15);
        }

        return key.getBytes(StandardCharsets.UTF_8);
    }

    public String encode(String raw) {
        if (raw == null) {
            return null;
        }

        byte[] data = aes.encrypt(raw.getBytes(StandardCharsets.UTF_8));
        return HexUtil.encodeHexStr(data);
    }

    public String decode(String encodedHex) {
        if (encodedHex == null) {
            return null;
        }

        byte[] data = aes.decrypt(HexUtil.decodeHex(encodedHex));
        return new String(data);
    }
}
