import {client, processResponse} from '../client';
import {apiUrls} from "app/src/api/api-urls";
import qs from "qs";

const classApi = {
  list, add, getInfo, update, duplicateClasses, deleteClass, getScheduleForCourse
}

export default classApi

async function list(courseId, page, pageSize) {
  const response = await client.get(apiUrls.class.list, {
    params: {
      course: courseId,
      page: page,
      pageSize: pageSize
    }
  })

  return processResponse(response)
}

async function getInfo(id) {
  const response = await client.get(apiUrls.class.info, {
    params: {id: id}
  })

  return processResponse(response)
}

async function add(data) {
  const response = await client.post(apiUrls.admin.class.add, data)

  return processResponse(response)
}

async function update(id, data) {
  const response = await client.post(
    apiUrls.admin.class.update,
    data, {
      params: {id: id}
    })

  return processResponse(response)
}

async function deleteClass(id) {
  const response = await client.post(apiUrls.admin.class.delete, undefined, {
    params: {id: id}
  })

  return processResponse(response)
}

async function duplicateClasses(id, source, target) {
  const response = await client.post(apiUrls.admin.class.duplicate, qs.stringify({
    course: id,
    from: source,
    to: target
  }))

  return processResponse(response)
}

async function getScheduleForCourse(course, term) {
  const response = await client.get(apiUrls.class.fromCourse, {
    params: {
      course: course,
      term: term,
    }
  })

  return processResponse(response)
}
