import axios from 'axios'
import {config as dev} from "app/env.dev";
import {config as prod} from "app/env.prod";
import axiosRetry from "axios-retry";

let baseUrl = ''

const env = process.env.NODE_ENV;
console.info(env + " env")
switch (env) {
  case 'production':
    baseUrl = prod.baseUrl
    break
  default:
    baseUrl = window.location.origin + "/api/v1"
}

const client = axios.create({
  // headers: {},
  baseURL: baseUrl,
  timeout: 8000,
  withCredentials: true
})

axiosRetry(client, {
  retries: 3,
  shouldResetTimeout: true
})

function processResponse(response) {
  const json = response.data
  if (json.code !== 20000) {
    throw {code: json.code, message: json.msg}
  }

  return json.data
}

export {
  client, processResponse
}
