import {client, processResponse} from '../client';
import {apiUrls} from "app/src/api/api-urls";
import qs from "qs";

const courseApi = {
  list, add, getInfo, update, deleteCourse, exportStudentExcel,
  student: {
    getCandidate, getSelected, getOfficial, select
  },
  teacher: {
    getTeacherCourseSchedule
  }
}

export default courseApi

async function list(page, pageSize) {
  const response = await client.get(apiUrls.course.list, {
    params: {
      page: page,
      pageSize: pageSize
    }
  })

  return processResponse(response)
}

async function getInfo(id) {
  const response = await client.get(apiUrls.course.info, {
    params: {id: id}
  })

  return processResponse(response)
}

async function add(data) {
  const request = {
    name: data.name === '' ? undefined : data.name,
    courseHours: data.courseHours === '' ? undefined : data.courseHours,
    targetMajor: data.targetMajor === '' ? undefined : data.targetMajor,
    targetGrade: data.targetGrade === '' ? undefined : data.targetGrade,
    springTerm: data.springTerm === '' ? undefined : data.springTerm,
  }

  const response = await client.post(apiUrls.admin.course.add, request)

  return processResponse(response)
}

async function update(id, data) {
  const request = {
    name: data.name === '' ? undefined : data.name,
    courseHours: data.courseHours === '' ? undefined : data.courseHours,
    targetMajor: data.targetMajor === '' ? undefined : data.targetMajor,
    targetGrade: data.targetGrade === '' ? undefined : data.targetGrade,
    springTerm: data.springTerm === '' ? undefined : data.springTerm,
  }

  const response = await client.post(
    apiUrls.admin.course.update,
    request, {
      params: {id: id}
    })

  return processResponse(response)
}

async function deleteCourse(id) {
  const response = await client.post(apiUrls.admin.course.delete, undefined, {
    params: {id: id}
  })

  return processResponse(response)
}

async function getCandidate() {
  const response = await client.get(apiUrls.student.course.candidate)
  return processResponse(response)
}

async function getSelected(term) {
  const response = await client.get(apiUrls.student.course.selected, {
    params: {
      term: term
    }
  })
  return processResponse(response)
}

async function getOfficial(term) {
  const response = await client.get(apiUrls.student.course.official, {
    params: {
      term: term
    }
  })

  return processResponse(response)
}

async function select(schedule, activity) {
  const data = {
    schedule: schedule,
    activity: activity
  }
  const response = await client.post(apiUrls.student.course.select, qs.stringify(data))

  return processResponse(response)
}

async function getTeacherCourseSchedule(term) {
  const response = await client.get(apiUrls.teacher.courseSchedule.list, {
    params: {
      term: term
    }
  })

  return processResponse(response)
}

async function exportStudentExcel(id, scheduleName) {
  const response = await client.get(apiUrls.class.studentList, {
    params: {id: id},
    responseType: "blob"
  })

  let data = response.data

  if (response.headers.getContentType() !== 'application/octet-stream' || data === undefined) {
    return processResponse(response)
  }

  const a = document.createElement('a')
  a.style.display = 'none'
  a.href = window.URL.createObjectURL(new Blob([data]))
  a.setAttribute('download', `export_students_${scheduleName}_${id}.xlsx`)
  document.body.appendChild(a)
  a.click()
  window.URL.revokeObjectURL(a.href)
  document.body.removeChild(a)

  return undefined
}
