import {client, processResponse} from '../client';
import {apiUrls} from "app/src/api/api-urls";
import qs from "qs";

const scoreApi = {
  exportScoreExcel,
  student: {
    getStudentAllScore
  },
  teacher: {
    getScheduleStudentScore, updateScore
  }
}

export default scoreApi

async function getStudentAllScore() {
  const response = await client.get(apiUrls.student.score.all)
  return processResponse(response)
}

async function getScheduleStudentScore(id) {
  const response = await client.get(apiUrls.teacher.score.scheduleScore, {
    params: {
      id: id
    }
  })

  return processResponse(response)
}

async function updateScore(schedule, scoreData) {
  const response = await client.post(apiUrls.teacher.score.update, scoreData, {
    params: {
      schedule: schedule,
      scoreId: scoreData.id,
    }
  })

  return processResponse(response)
}

async function exportScoreExcel(id, scheduleName) {
  const response = await client.get(apiUrls.score.export, {
    params: {id: id},
    responseType: "blob"
  })

  let data = response.data

  if (response.headers.getContentType() !== 'application/octet-stream' || data === undefined) {
    return processResponse(response)
  }

  const a = document.createElement('a')
  a.style.display = 'none'
  a.href = window.URL.createObjectURL(new Blob([data]))
  a.setAttribute('download', `export_score_${scheduleName}_${id}.xlsx`)
  document.body.appendChild(a)
  a.click()
  window.URL.revokeObjectURL(a.href)
  document.body.removeChild(a)

  return undefined
}
